@@ -9,3 +9,6 @@ COPY_DB_DELIMITER = '\x1f'
 
 # Filename of the default schema
 DEFAULT_SCHEMA_FILE = 'schema.yml'
+
+# Default chunk size for data fetch
+DEFAULT_CHUNK_SIZE = 2000
